package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`+<````!````````()``````````0```````
M`*2P``````!``#@`"`!``!D`&`````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````%P`````````7``````````$````!
M````!0```````````````````````````````````````)SL````````G.P`
M``````$```````$````&````````G4````````&=0````````9U`````````
M!3@````````%R````````0```````@````8```````"=6````````9U8````
M```!G5@````````!X`````````'@``````````@````$````!`````````(8
M`````````A@````````"&``````````L`````````"P`````````!&1TY5``
M```$````````E6````````"58````````)5@`````````/P`````````_```
M```````$9'3E4@````0```````"=0````````9U````````!G4`````````"
MP`````````+```````````$O=7-R+VQI8F5X96,O;&0N96QF7W-O```````'
M````!`````%.971"4T0``#N:R@`````$````!`````-085@`````````````
M``!A````9@``````````````,0````X``````````````#@````/````0```
M```````P``````````,```!,````7P`````````@````2P````8````>````
M%0````````!"`````````%L`````````&````#P```!6``````````````!B
M````9````"\````3````50```$0````6````6@```$4`````````2````",`
M```U````60```"<````K``````````<```!.``````````P````+````90``
M`%@```!*````(0```$,```!C`````````%T`````````&0```"X```!-````
M````````````````$@```#,`````````"@```%X````L``````````D`````
M````)0```#D`````````3P````4```!&````'````#L`````````````````
M````````20`````````Z````4@```&``````````80``````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````4````````````````````````````
M````````````````````````)````"(`````````*@`````````H````*0``
M`"T```````````````T`````````'0```!L````:```````````````1````
M`````#0````R````-P```!\`````````````````````````!```````````
M````00```"8````````````````````7```````````````_````"```````
M`````````````#X```!1`````````%0``````````````#T`````````````
M`%``````````1P```!``````````4P```%<````V````7```````````````
M``````````````````````````````````,```H````````@D```````````
M``````,``!````````&=4```````````````F1(`````````````````````
M````````#!(`````````````````````````````%!(`````````````````
M```````````#6!(```H````````ID``````````(````'"(`````````````
M````````````````*Q(````````````````````````````"_Q(`````````
M````````````````````,1(````````````````````````````#,1```!4`
M``````&B>```````````````.!(````````````````````````````#:1(`
M``H````````SH``````````@````/Q(````````````````````````````#
M#!(`````````````````````````````1Q(`````````````````````````
M```#A!(```H````````](`````````!D````BA(`````````````````````
M```````#0!```!4```````&C"```````````````3Q(`````````````````
M```````````#D!```!0```````&B>```````````````7Q(`````````````
M````````````````;A(`````````````````````````````=!(`````````
M````````````````````>Q(`````````````````````````````A1(`````
M````````````````````````CQ(````````````````````````````#/Q``
M`!4```````&C"```````````````F!(````````````````````````````"
M"A(`````````````````````````````GA(`````````````````````````
M````I1(`````````````````````````````LQ(`````````````````````
M````````Q!$````````````````````````````"D"(`````````````````
M````````````T1(````````````````````````````#EQ(```H````````K
MQ``````````L```#I!(```H````````K\`````````!L```#L!(```H`````
M```TY`````````7`````WQ8`````````````````````````````\A(`````
M```````````````````````#'A(`````````````````````````````_1(`
M```````````````````````````!!A$``!4```````&C```````````(```!
M#A(````````````````````````````"]1(`````````````````````````
M```!&A(````````````````````````````!(1(`````````````````````
M```````#O1(```H```````!.1`````````$D```!-!$`````````````````
M```````````!1A(````````````````````````````!5A(`````````````
M```````````````!9!(````````````````````````````!:1(`````````
M```````````````````#R!$``!0```````&B<``````````(```!>!(`````
M```````````````````````!A!(````````````````````````````!F1(`
M```````````````````````````!I!(````````````````````````````#
M4Q```!4```````&C"``````````````"MA(`````````````````````````
M```!MQ(````````````````````````````$`Q(```H````````@D```````
M```(```!Q1(````````````````````````````!S1(`````````````````
M```````````!V1(````````````````````````````#2Q```!4```````&C
M"``````````````#TA(```H````````L8`````````3$```!WQ(`````````
M```````````````````!ZA(````````````````````````````#WQ(```H`
M``````!/<`````````&X```!^Q(````````````````````````````#Z1``
M`!4```````&B>``````````````#]1(```H````````H\`````````!````#
M_1(```H```````!1\`````````(8```"`A(`````````````````````````
M```"<2(````````````````````````````$`A(```H````````@D```````
M```(```$"A(```H````````IH`````````(D```$%Q(```H````````SP```
M``````$D```""1(````````````````````````````$*1(```H````````Q
M)`````````!P```"$A(````````````````````````````"B1(`````````
M```````````````````$-Q(```H````````QE`````````"<```"(Q(`````
M```````````````````````"+!(````````````````````````````",A(`
M```````````````````````````"Z!(````````````````````````````"
M-Q(````````````````````````````"VQ$``!4```````&BB``````````(
M```"/Q(````````````````````````````#$Q(`````````````````````
M```````"1A(````````````````````````````$/Q(```H```````!-\```
M``````!4```"31$````````````````````````````"T!$``!0```````&A
M\``````````(```$2!(```H````````ZI`````````)X```!+1(`````````
M```````````````````"4A(````````````````````````````#)1(`````
M`````````````````````&QI8G!E<FPN<V\`<F5A;&QO8P!M96UM;W9E`%]?
M8WAA7V9I;F%L:7IE`')M9&ER`'-T<G-T<@!S=')C:'(`<W1R;F-M<`!S=')R
M8VAR`&)O;W1?1'EN84QO861E<@!P97)L7V-O;G-T<G5C=`!A8F]R=`!U;FQI
M;FL`7U]L<W1A=#4P`'!E<FQ?9G)E90!?7W-T870U,`!?97AI=`!M96UC<'D`
M<&5R;%]D97-T<G5C=`!?7W-T86-K7V-H:U]F86EL`%!,7V1O7W5N9'5M<`!0
M97)L7W-V7W-E='!V`%!,7V-U<G)E;G1?8V]N=&5X=`!P97)L7V%L;&]C`&-L
M;W-E9&ER`&5N=FER;VX`7U]O<&5N9&ER,S``;65M<V5T`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!?7W-T86-K7V-H:U]G=6%R9`!097)L7V=V7V9E=&-H<'8`7U]S
M<')I;G1F7V-H:P!R96%D`%!E<FQ?<WES7VEN:70S`%!E<FQ?9V5T7W-V`%!E
M<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;F5W6%,`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?<WES7W1E<FT`7U]E<G)N;P!097)L7VUG7W-E=`!M:V1I<@!P
M97)L7W!A<G-E`%!E<FQ?;F5W6%-?9FQA9W,`86-C97-S`&=E='!I9`!V9G!R
M:6YT9@!097)L7V%T9F]R:U]L;V-K`'!E<FQ?<G5N`&QS965K`&]P96X`<W!R
M:6YT9@!G971U:60`<W1R;&5N`%]?<T8`<W1R8VUP`&QI8FTN<V\N,`!L:6)C
M<GEP="YS;RXQ`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O`'-T<F1U<`!?7W)E
M9VES=&5R7V9R86UE7VEN9F\`;&EB<'1H<F5A9"YS;RXQ`'!T:')E861?871F
M;W)K`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S7W-T<FEN9W,`7U]G971P
M=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`871E>&ET`%]L:6)C7VEN
M:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]?8G-S7W-T87)T7U\`7U]B<W-?96YD
M7U\`7U]E;F1?7P!?96YD`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`'!A<E]B87-E;F%M
M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!M>5]P87)?
M<&P`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET
M`&UA:6X`7U]S=&%R=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET`%A37TEN=&5R;F%L<U]0
M05)?0D]/5``O=7-R+W!K9R]L:6(O<&5R;#4O-2XS."XP+V%A<F-H-C1E8BUN
M971B<V0M=&AR96%D+6UU;'1I+T-/4D4Z+W5S<B]P:V<O;&EB`````````9U`
M````````!`,```````!1L````````9U(````````!`,```````!1,```````
M`9]`````````!`,```````&=4````````9]8````````!`,```````&=0```
M`````9]X````````!`,```````&C`````````9^(````````!`,```````&=
M2````````9^0````````!`,```````&B<````````9^P````````!`,`````
M``&=6````````9_(````````!`,```````&BB````````9_8````````!`,`
M``````&A\````````9_@````````!`,````````ZI````````:'P````````
M!`,```````&B@````````:'X````````!`,```````&A^````````:(0````
M````!`,```````!4(````````:(8````````!`,```````!4*````````:(H
M````````!`,```````!4,````````:(P````````!`,```````!40```````
M`:(X````````!`,```````!42````````:)`````````!`,```````!44```
M`````:)(````````!`,```````!46````````:)8````````!`,```````!4
M8````````:)@````````!`,```````!4:````````:)P````````!`,`````
M``!7V````````9](````!P``!`$``````````````````9]0````%```!`$`
M`````````````````9]@````(@``!`$``````````````````9]H````(P``
M!`$``````````````````9]P````*```!`8``````````````````9^`````
M,@``!`$``````````````````9^8````.P``!`$``````````````````9^H
M````30``!`$``````````````````9_`````4P``!`$`````````````````
M`9_0````8```!`$``````````````````:```````P``!`(`````````````
M`````:`(````!```!`(``````````````````:`0````!0``!`(`````````
M`````````:`8````!P``!`(``````````````````:`@````"```!`(`````
M`````````````:`H````"0``!`(``````````````````:`P````"@``!`(`
M`````````````````:`X````#```!`(``````````````````:!`````#@``
M!`(``````````````````:!(````#P``!`(``````````````````:!0````
M$```!`(``````````````````:!8````$@``!`(``````````````````:!@
M````%@``!`(``````````````````:!H````%P``!`(`````````````````
M`:!P````&```!`(``````````````````:!X````&0``!`(`````````````
M`````:"`````&@``!`(``````````````````:"(````&P``!`(`````````
M`````````:"0````'0``!`(``````````````````:"8````'@``!`(`````
M`````````````:"@````'P``!`(``````````````````:"H````(```!`(`
M`````````````````:"P````(0``!`(``````````````````:"X````(P``
M!`(``````````````````:#`````)```!`(``````````````````:#(````
M*0``!`(``````````````````:#0````*@``!`(``````````````````:#8
M````*P``!`(``````````````````:#@````+0``!`(`````````````````
M`:#H````+@``!`(``````````````````:#P````+P``!`(`````````````
M`````:#X````,```!`(``````````````````:$`````,P``!`(`````````
M`````````:$(````-```!`(``````````````````:$0````-0``!`(`````
M`````````````:$8````-@``!`(``````````````````:$@````.```!`(`
M`````````````````:$H````.0``!`(``````````````````:$P````.@``
M!`(``````````````````:$X````/0``!`(``````````````````:%`````
M/@``!`(``````````````````:%(````0```!`(``````````````````:%0
M````00``!`(``````````````````:%8````0@``!`(`````````````````
M`:%@````10``!`(``````````````````:%H````1@``!`(`````````````
M`````:%P````2```!`(``````````````````:%X````3```!`(`````````
M`````````:&`````30``!`(``````````````````:&(````40``!`(`````
M`````````````:&0````5```!`(``````````````````:&8````5@``!`(`
M`````````````````:&@````5P``!`(``````````````````:&H````6```
M!`(``````````````````:&P````60``!`(``````````````````:&X````
M6@``!`(``````````````````:'`````7```!`(``````````````````:'(
M````70``!`(``````````````````:'0````7@``!`(`````````````````
M`:'8````8P``!`(``````````````````:'@````9```!`(`````````````
M`````:'H````90``!`(``````````/![OZG0``"0$?Y'^1#B/Y$@`A_6'R`#
MU1\@`]4?(`/5T```L!$"0/D0`@"1(`(?UM```+`1!D#Y$"(`D2`"'];0``"P
M$0I`^1!"`)$@`A_6T```L!$.0/D08@"1(`(?UM```+`1$D#Y$((`D2`"'];0
M``"P$19`^1"B`)$@`A_6T```L!$:0/D0P@"1(`(?UM```+`1'D#Y$.(`D2`"
M'];0``"P$2)`^1`"`9$@`A_6T```L!$F0/D0(@&1(`(?UM```+`1*D#Y$$(!
MD2`"'];0``"P$2Y`^1!B`9$@`A_6T```L!$R0/D0@@&1(`(?UM```+`1-D#Y
M$*(!D2`"'];0``"P$3I`^1#"`9$@`A_6T```L!$^0/D0X@&1(`(?UM```+`1
M0D#Y$`("D2`"'];0``"P$49`^1`B`I$@`A_6T```L!%*0/D00@*1(`(?UM``
M`+`13D#Y$&("D2`"'];0``"P$5)`^1""`I$@`A_6T```L!%60/D0H@*1(`(?
MUM```+`16D#Y$,("D2`"'];0``"P$5Y`^1#B`I$@`A_6T```L!%B0/D0`@.1
M(`(?UM```+`19D#Y$"(#D2`"'];0``"P$6I`^1!"`Y$@`A_6T```L!%N0/D0
M8@.1(`(?UM```+`1<D#Y$((#D2`"'];0``"P$79`^1"B`Y$@`A_6T```L!%Z
M0/D0P@.1(`(?UM```+`1?D#Y$.(#D2`"'];0``"P$8)`^1`"!)$@`A_6T```
ML!&&0/D0(@21(`(?UM```+`1BD#Y$$($D2`"'];0``"P$8Y`^1!B!)$@`A_6
MT```L!&20/D0@@21(`(?UM```+`1ED#Y$*($D2`"'];0``"P$9I`^1#"!)$@
M`A_6T```L!&>0/D0X@21(`(?UM```+`1HD#Y$`(%D2`"'];0``"P$:9`^1`B
M!9$@`A_6T```L!&J0/D00@61(`(?UM```+`1KD#Y$&(%D2`"'];0``"P$;)`
M^1""!9$@`A_6T```L!&V0/D0H@61(`(?UM```+`1ND#Y$,(%D2`"'];0``"P
M$;Y`^1#B!9$@`A_6T```L!'"0/D0`@:1(`(?UM```+`1QD#Y$"(&D2`"'];0
M``"P$<I`^1!"!I$@`A_6T```L!'.0/D08@:1(`(?UM```+`1TD#Y$((&D2`"
M'];0``"0$=9`^1"B!I$@`A_6T```D!':0/D0P@:1(`(?UM```)`1WD#Y$.(&
MD2`"'];0``"0$>)`^1`"!Y$@`A_6T```D!'F0/D0(@>1(`(?UM```)`1ZD#Y
M$$('D2`"'];0``"0$>Y`^1!B!Y$@`A_6T```D!'R0/D0@@>1(`(?UM```)`1
M]D#Y$*('D2`"'];A`P*J-```%```````````_7N]J:```/#]`P"1`*!'^?43
M`/FU``#PM2(UD;\"`.N"`0!4\U,!J10$`-&4`A7+$P"`TI3^0].@>G/X```_
MUG\"%.MS!@"1@?__5/-30:GU$T#Y_7O#J,`#7]8?(`/5_7N]J?T#`)'S4P&I
MLP``\/43`/FU``#P<])'^;7>1_E_`A7K8@$`5&`.0+D?(!#Q@0$`5'0"0/ES
M8@"18()?^```/]:``@#Y?P(5Z^/^_U3S4T&I]1-`^?U[PZC``U_6"/__E_U[
MO*G]`P"1\U,!J?5;`JGW&P#Y80D`M/0#`:JA``#PM0``\"'D1_F"`D#YI+Y'
M^4,`0/DT``#Y@0I`^8$``/FA``#P(P<`M"'L1_DC``#Y0@!`^4,`0#GC```T
M0@0`D7^\`'&!__]4(@``^4,`0#EC__\U0```M-G^_Y>8__^7H```\`#81_G`
M!@"TH```\+<``/#W`C61`*Q'^?\"`.M"`0!4%@0`T1,`@-+6`A?+UOY#T^!Z
M<_@``#_6?P(6ZW,&`)&!__]4````D`"``I'#_O^7MP``\*```/#W`C61`,1'
M^?\"`.M"`0!4%@0`T1,`@-+6`A?+UOY#T^!Z<_@``#_6WP(3ZW,&`)&!__]4
MM;Y'^8`*0+F!`D#YH@)`^=L+`)2*_O^7(>Q'^<(``)!"``J1(@``^0#Z_[70
M__\7`@``\$(@$)%C`H#200"`4H``@-+R_O^7(`"`4L3^_Y>/__^7RO__%P``
M``#]>[RI_0,`D?-3`:F@!@"T]V,#J?<#`*J@``#P`+Q'^1@`0/DX!@"T]5L"
MJ?8#`:H5`(!2X`)`.1_T`'$$&$!ZP0(`5!,#0/G3`0"TM7Y`D_0#&*H?(`/5
MX@,5JN$#%ZK@`Q.J?_[_EX```#5@:G4X'_0`<0`"`%23CD#X\_[_M?5;0JGW
M8T.IX`,3JO-30:G]>\2HP`-?UO4#%ZJ@'D`X'_0`<0080'JA__]4M0(72^7_
M_Q>4`AC+M08`D7,"%8N4_D.3U`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2HP`-?
MUA,`@-+I__\7$P"`TO=C0ZGF__\7_7NRJ:$``/#]`P"1(<!'^2(`0/GB;P#Y
M`@"`TL```+3S4P&I\P,`J@$`0#EA`0`U\U-!J:```/``P$?YX6]`^0(`0/DA
M``+K`@"`TN$(`%3]>\ZHP`-?UI7^_Y?T`P"J@/[_M/=C`ZD7``#P^`,!D??B
M$9'U6P*IX`,4JA#__Y<@!0"T`31`.14T`)$_N`!Q80``5*$&0#D!__\T`#1`
M.1^X`'$`!0!4X`,3JOC^_Y?V`P"JX`,5JO7^_Y?``@`+``@`$0!\0)/U_O^7
MXP,5JN(#$ZKU`P"JX0,7JN#^_Y?A`QBJX`,5JD7^_Y<?!``QH```5.!+0+D`
M#!02'Q!`<>`"`%3@`Q6J,?[_E^`#%:HC_O^7X`,4JNG^_Y=`^_^U'R`#U>`#
M%*I=_O^7X`,3JO_]_Y?S4T&I]5M"J?=C0ZF]__\7H`9`.1^X`''A^O]4H`I`
M.2#Y_S34__\7X`,5JJC__Y?J__\7\U,!J?5;`JGW8P.I-O[_EQ\@`]7]>[2I
MH@``\/T#`)%"P$?Y\PL`^>&#`)'S`P"J0P!`^>-?`/D#`(#2#O[_ER`"`#7A
M*T"Y`@"44B$,%!(_$$!Q)!!">J`!`%2A``#P(<!'^>)?0/DC`$#Y0@`#ZP,`
M@-*!`0!4\PM`^?U[S*C``U_6``"`4O7__Q?@`Q.J00"`4G3^_Y<?``!QX!>?
M&N___Q<0_O^7_\,0T:,``/#A`P"J`H"`TOU[`*G]`P"18\!'^?,+`/GSHP"1
M9`!`^>07`OD$`(#2X`,3JK[]_Y<`!`#1'P`3ZZ@``%0'```4'_0?.!\`$^N`
M``!4`0!`.3^\`'%@__]4X`,3JN$%@%+%_?^70`(`M!\`$^O(`0!4X`,3JF#^
M_Y>A``#P(<!'^>(70ODC`$#Y0@`#ZP,`@-*!`@!4_7M`J?,+0/G_PQ"1P`-?
MUA\``#GR__\7H```\`#`1_GA%T+Y`@!`^2$``NL"`(#2X0``5/U[0*D```#P
M\PM`^0"@$)'_PQ"11O[_%]7]_Y?]>[JIH@``\/T#`)'S4P&I\P,`JO0#`:KU
M6P*I]V,#J4+`1_D@`$`Y00!`^>$O`/D!`(#2'_0`<906E)K@`Q2J5/[_E_8#
M`*KA4P&1X`,3JO#^_Y=`"`"T]0,`JDW^_Y??`@#KZ08`5/=7@+FX``#P]_)]
MTV`"0#D?]`!Q!!A`>D`,`%3C`Q.J8AQ`.%_T`'%$&$!ZH?__5&,`$\MC?$"3
M&+]'^<`*`)$```.+%@-`^3S^_Y?`:C?XP`(`M.-7@+G@`Q.J`@-`^0$40#A#
M>&/X/_0`<2080'IA```YP```5`(40#AB'``X7_0`<4080'J!__]4H0>`4@``
M@-)A%``X@FI@.&)H(#@`!`"1HO__-:```/``P$?YX2]`^0(`0/DA``+K`@"`
MTJ$'`%3S4T&I]5M"J?=C0ZG]>\:HP`-?U@$`@-(?(`/5@FIA.*)J(3@A!`"1
MHO__->[__Q>X``#P^6L$J0"_1_D:`$#Y0`-`^0`%`+3@`QJJ%0"`4A\@`]4!
MC$#XX@,5*K4&`!&A__^U0`P`$0!\?9/!``"0(N!"N2("`#4B`(!2(N`"N?W]
M_Y?Y`P"J@`,`M+=^?9/A`QJJX@,7JA/]_Y<`OT?Y&0``^:`&`!$_VR#X]5<`
MN?EK1*FE__\7X0,`JN`#&JH%_?^7^0,`J@&_1_D@``#Y0`$`M+=^?9/S__\7
M`P"`TJ7__Q<``H#2%0"`4N#__Q?Y:P2I3/W_E_EK1*FZ__\7'R`#U?U[OZE!
MT#O5H@``\/T#`)&@``#P`+A'^1\@`]4?(`/5_7O!J",``/!"J$?Y8R`5D2!H
M8/@!``#P(0`2D7G]_Q?]>[ZI0=`[U?T#`)'S"P#YH```\`"X1_D?(`/5'R`#
MU3,``(L@:&#XYO__EZ(``/`$``#P8`)`^80`'Y'S"T#YXP,$JOU[PJ@!``#P
M0O!'^2&`$I$%`(!2?OW_%Q\@`]4``(#2P`-?UA\@`]4?(`/5_P,4T:(``/#]
M>P"I_0,`D4+`1_GS4P&I\P,!JO5;`JGA<P&1]0,`JD,`0/GC?P+Y`P"`T@``
M`/``X!*1/?[_E_0#`*KA!8!2X`,5JLW\_Y=``@"TX0,5J@```/``(!.1,/__
ME^`#%:JA``#P(<!'^>)_0ODC`$#Y0@`#ZP,`@-+!#`!4_7M`J?-30:GU6T*I
M_P,4D<`#7];@`Q.J9?W_EQ8``/#!8A.1`OW_E_,#`*H@_?^T]V,#J1@``/`7
M``#P&*,0D?>"$Y'Y(P#Y'R`#U6`"0#G@!@`TM```M.$#$ZK@`Q2J>_W_ET`%
M`#3@`Q.J</W_EP($`-'Y`P"J8@("BW\"`NNC``!4"@``%%_T'SA_`@+K@```
M5$$`0#D_O`!Q8/__5.`#$ZIB_?^7^0,`JN`#%:I?_?^7&0`9BSD'`)$__P_Q
M"`,`5.0#$ZKF`Q6JY0,7J@,``/!CH!.1\^,#D0*`@-(!`(!2X`,3JNW\_Y?@
M`Q.JX8,!D:K\_Y>@```UX&M`N0`,%!(?($!Q8`(`5,%B$Y$``(#2QOS_E_,#
M`*J`^?^U]V-#J?DC0/FJ__\7]`(`M(`"0#D?N`!Q@```5/,#&*HY`(#2VO__
M%X`&0#D`_O\T^___%^`#$ZHA`(!2!/W_EV#]_S7A`Q.J````\``@$Y'+_O^7
MX`,3J@W]_Y?W8T.I^2-`^9C__Q?S`QBJ.0"`TL?__Q?W8P.I^2,`^93\_Y?]
M>[ZIX06`4OT#`)'S"P#Y\P,`JE[\_Y<?``#Q8`:`FO,+0/G]>\*H^?S_%P`#
M`+3]>[ZI_0,`D?,+`/GS`P"J`0!`.2$!`#01_?^7``0`D1\`$/%(`0!4X`,3
MJO,+0/G]>\*H:_[_%_,+0/D```#P_7O"J`"@$)'E_/\7``"`TO,+0/G]>\*H
MP`-?U@```/``H!"1WOS_%Q\@`]7]>[JIH```\/T#`)$`P$?Y]5L"J;4``/#S
M4P&I%```\/-3`9'W8P.IE,(3D?DC`/FUOD?Y`0!`^>$O`/D!`(#2X0,3JN`#
M%*J*_?^7X`$`M*("0/GC5X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``
MD:'__[7A`Q.JX`,4JGS]_Y=@_O^UM0``\!0``/"4`A21M;Y'^>$#$ZK@`Q2J
M=/W_E^`!`+2B`D#YXU>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A
M__^UX0,3JN`#%*IF_?^78/[_M;4``/`4``#PE"(4D;6^1_GA`Q.JX`,4JE[]
M_Y?@`0"TH@)`^>-7@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__
MM>$#$ZK@`Q2J4/W_EV#^_[6U``#P%```\)1B%)&UOD?YX0,3JN`#%*I(_?^7
MX`$`M*("0/GC5X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A
M`Q.JX`,4JCK]_Y=@_O^UM0``\!0``/"6@A21M;Y'^>$#$ZK@`Q:J,OW_E^`!
M`+2B`D#YXU>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3
MJN`#%JHD_?^78/[_M;8``/`5``#PM<(4D=:^1_GA`Q.JX`,5JAS]_Y?@`0"T
MP@)`^>-7@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@
M`Q6J#OW_EV#^_[6V``#P%0``\+?B$I'6OD?YX0,3JN`#%ZH&_?^7X`$`M,("
M0/GC5X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,7
MJOC\_Y=@_O^UMP``\!8``/#8`A61][Y'^>$#$ZK@`QBJ\/S_E^`!`+3B`D#Y
MXU>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#&*KB
M_/^78/[_M;@``/`7``#P^4(5D1B_1_GA`Q.JX`,9JMK\_Y?@`0"T`@-`^>-7
M@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QFJS/S_
MEV#^_[6Y``#P&```\!B#%9$YOT?YX0,3JN`#&*K$_/^7X`$`M"(#0/GC5X"Y
M0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,8JK;\_Y=@
M_O^UN0``T!@``-`8(Q.1.;]'^>$#$ZK@`QBJKOS_E^`!`+0B`T#YXU>`N4`,
M`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#&*J@_/^78/[_
MM>$#$ZH```#0`,`5D9O\_Y?A`P"J8```M.!"%9&3_?^7X0,3J@```-``(!:1
MD_S_E^$#`*J```"T````T`#`$)&*_?^7X0,3J@```-``@!:1BOS_E^$#`*I@
M`@"TH.(2D8+]_Y>@``#0`,!'^>$O0/D"`$#Y(0`"ZP(`@-)A`@!4@((4D0$`
M`-#S4T&I(2`7D?5;0JGW8T.I^2-`^?U[QJAR_?\7X0,3J@```-``P!:1<OS_
ME^$#`*I@_?^TP`(5D6K]_Y?H__\7//O_E_U[OJFB``#0````T/T#`)%"P$?Y
MX5,`D0``%9%#`$#YXP\`^0,`@-)A_/^7P`$`M```0#D?P`!Q!!A`>N`'GQJA
M``#0(<!'^>(/0/DC`$#Y0@`#ZP,`@-*A``!4_7O"J,`#7]8``(!2]O__%R#[
M_Y?]>ZZIJ```T.P&@!+]`P"1"L%'^>`;@#WM@P.1X1^`/>L/@!+H0P"1XB.`
M/:D``-#C)X`]Y"N`/>4O@#WF,X`]YS>`/>&+#JGA`P"JX@,(JN.3#ZGEFQ"I
MYX\`^2#I1_E#`4#YXR\`^0,`@-+C@P21XX\#J0#`!)'M)P#Y["\**>270ZGD
M%P&IY)=$J005`:EG^_^7X!^`4J'Z_Y?_0P'1HP``T/]#0-$!`(#2Y$-`D4(`
M@%+]>P"I_0,`D6/`1_GS4P&I]`,`*F4`0/F%)`#Y!0"`TF+[_Y<`!`#1\P,`
MZP$\0))S/D"2,T23VA,`$^O$!P!4]5L"J18``-`5`8#2UH(7D?=C`ZD7``#0
M^`,!D?="%Y$U`*#R'R`#U>$#$ZK@`Q0J`@"`4DW[_Y<?!`"Q``8`5.$#&*KB
M`Q6JX`,4*O_Z_Y<!?$"3'P0`,0`$`%0_'`#Q"00`5"$@`-$!`P&KH@,`5*``
M`/`$```4(00`T3\`&.L#`P!4`P!!^2(`0/E_``+K0?__5"``&,OU6T*I```3
MB_=C0ZFA``#0XD-`D2'`1_E#)$#Y)`!`^6,`!.L$`(#200(`5/U[0*GS4T&I
M_T,!D?]#0)'``U_6X`,6JHS__Y=S0D#1?T)`L0'Z_U3U6T*I]V-#J0``@)+K
M__\7X`,7JH/__Y?/__\7]5L"J?=C`ZF>^O^7'R`#U?U[OZG]`P"1(OO_EQG[
M_Y=```"T``!`^?U[P:C``U_6_7N\J:(``-#]`P"10L!'^?-3`:GATP"1]5L"
MJ14``-"VPA>10P!`^>,?`/D#`(#2]`,`JN`#%JJV^_^7@```M`$`0#GS`P"J
MP0$`-:```-``P$?YX1]`^0(`0/DA``+K`@"`TN$%`%3A`Q2JH,(7D?-30:GU
M6T*I_7O$J*'\_Q?A`Q2J,_K_EX`!`+2@``#0`,!'^>$?0/D"`$#Y(0`"ZP(`
M@-+A`P!4\U-!J?5;0JG]>\2HP`-?UN`#%*KU^O^7]0,`JN`#$ZKR^O^7H`(`
MBP`(`)'S^O^7Y`,3JN(#%*KS`P"J`P``T`$``-!C8!.1(:`3D=OZ_Y>B``#0
M0L!'^>`?0/E!`$#Y```!ZP$`@-*!``!4X0,3JN`#%JK5__\73/K_E_U[IZFB
M``#PH0``T$(`")']`P"1(<!'^?-3`:GC(P*1]5L"J?/#`9'U8P&1]V,#J?<#
M`*KT4P&11AQ!J2``0/G@QP#Y``"`TDJL0JGFGP6I&```T$BD0ZGA`Q2J1)1$
MJ0#C$I%,M$6I:"0!J4X00/FN"@#Y1C1`^68*`/ED%`*I[#<'J>JO"*E9^_^7
M@```M`$`0#GV`P"JX1X`-?EK!*F'__^7^0,`JL`;`+3@`QFJK_K_EP#X?],`
M!`"1L/K_ER(#0#GV`P"J8@$`-!H``-#S`Q:J6B,8D1\@`]7@`Q.JX0,:JI;Z
M_Y=S"@"1(A]`.&+__S4!``#0^4,"D2#`$)$#```4((=`^$`(`+3A`Q2J-_O_
ME_,#`*I@__^T`0!`.2'__S3.^_^7X/[_-.`#$ZIO^O^7\P,`JL`&`+3@`Q.J
MB_K_E_4#`*K@`Q:JB/K_E[D"``LY$Q`1&@``T#E_0)/@`QFJAOK_E^4#%JKB
M`Q.J0X,3D00``-"$0!B1]0,`J@$``-`A8!B1;?K_E^`#%:H!.(!2.OK_EQ\$
M`#$`$@!4X>,"D>`#%:K%^?^7\P,`*B`%`#2@``#0`0``T.("0/GC`Q6J`.A'
M^2&@&9$4`(#2`,`$D<KY_Y>@``#0`,!'^>''0/D"`$#Y(0`"ZP(`@-(A'@!4
MX`,4JO-30:GU6T*I]V-#J?EK1*G]>]FHP`-?UAD`@%*SVGGXLP$`M&`"0#E@
M`0`T.0<`$>`#$ZJ,^_^7(/__-.`#$ZHM^O^7\P,`JN#W_[6SVGGXL_[_M1,`
M@-*[__\7X,-`N0`,%!(?$$!QH?K_5/;70+DY^O^7WP(`:R'Z_U3@PT"Y`"``
M$A\`!W&A^?]4X`,9JCWZ_Y?A`Q2J]`,`J@```-```!N1U/K_E^$#`*I`$`"T
MX`)`^83\_Y?Y`P"JP`\`M.`#&:HL^O^7]@,`JA\,`''M`0!4`'Q`DP$``-``
M$`#1(2`;D2`#`(LK^O^7``$`-=\2`'&`%`!4UA8`42#+=C@?O`!Q`!0`5!\@
M`]5/_O^7P```->`#&:H!`(!2`OK_E_8#`"K`#``U`0``T````-`A(!>1```5
MD:O[_Y=:@Q.1%P``T/<"'Y'?^?^7&0``T.0#`"KE`Q>JXP,:JN(#%:K@`Q2J
M`0``T#DC')$AX!N1]?G_EP\``!2[^?^7``!`N1]$`'$!`@!4S_G_EW,&`!'D
M`P`JY0,3*N8#%ZKC`QJJX@,5JN$#&:K@`Q2JYOG_E^`#%*H!.(!2L_G_EQ\$
M`#'`_?]4X`,5JB_Y_Y?A`Q2J`.,2D83[_Y?@`Q2JPO[_EX#__Q>@^?^7``!`
MN1]$`''`[?]4\P)`^9OY_Y>E``#0!`!`N>(#$ZKC`Q6JI>A'^10`@-(!``#0
M(:`8D:#`!)$Y^?^7;___%Q8`@%)@VG;X@`$`M.$#%*K6!@`1;OK_EV#__[0!
M`$`Y(?__-*KY_Y?Y`P"J`./_M6#:=OC`_O^UH`&`TLCY_Y<9``#0]@,`JCD#
M&)%B"H!2%___%YK^_Y>@``#0`,!'^>''0/D"`$#Y(0`"ZP(`@-)!"0!4X`,6
MJO-30:GU6T*I]V-#J?U[V:B1^?\7^0)`^8+__Q<F_O^7]P,`JB#S_[<!*`#1
M`@"`4N`#%BKY0P61C_G_E^$#&:K@`Q8JP@"`TD/Y_Y<?&`#Q@```5````-``
M8!N1[_W_E^!30;D`T%!1``P%<>'P_U0A"T!YH`B)4C\``&MA\/]4X<H`T0(`
M@%+@`Q8J\V,%D7GY_Y?@`Q8JX0,3J@(%@-(M^?^7'Z``\8```%0```#0`&`;
MD=G]_Y?D`Q.J0X,3D>(#%:K@`Q2J!0``T`$``-"E`!^1(:`;D?\#!CER^?^7
MD?__%_8&0/DV[/^TX`,6JGGY_Y<?#`#QJ>O_5``0`-$!``#0P`(`BR%`&Y%Z
M^?^7'P``<3D3EII5__\7WOC_E_EK!*G<^/^7_7N[J:(``-`$``#0_0,`D?-3
M`:E3T#O5H```T`"X1_D?(`/5'R`#U?5;`JGU$P&1X0,5JO=C`ZEC:F#X@(`4
MD4+`1_EDP$(Y10!`^>4G`/D%`(#29,0".?7Y_Y>```"T`0!`.3_$`'&`"P!4
M5/S_EZ```-``N$?Y'R`#U1\@`]5V`@"+8&I@^`$``-!C`(!2(8`<D2(`@%+=
M^/^7]`,`JF`!`+0!"$#Y`@``T,`"0/E"H!R1(0!`^;7X_Y>`"D#Y`0!`^2`,
M0+D@"[`WH```T`"X1_D?(`/5'R`#U7<"`(M@:F#X`0``T&,`@%(AP!R1(@"`
M4K8``/#%^/^7]`,`JF`!`+3A`Q6J````T``@$Y''^?^7X@,`JD`'`+2!"D#Y
MX`)`^2$`0/F9^/^7H```T`"X1_D?(`/5'R`#U70"`(MS:F#X(@"`4@$``-`A
MX!R1X`,3JK[X_Y<"``#0X0,`JD)`'9'@`Q.JB?C_E].""Y&"`D#YX0,5J@``
M`-``X!*17\0".:KY_Y=@"@#YP`(`M`$X@%+*^/^7`00`$3\$`'$$B%%ZP04`
M5*```-``P$?YX2=`^0(`0/DA``+K`@"`TL$$`%3S4T&I]5M"J?=C0ZG]>\6H
MP`-?U@`$0#F@]/\TH___%V`&0/D6_O^78`H`^0#]_[4```#0`&`=D9CX_Y<[
M^_^7^`,`JH`!`+2!"D#YX@,`JN`"0/DA`$#Y7/C_E^`#&*HF^/^7P?__%\`"
M0/F?^/^7IO__%\"""Y&!"D#Y`@1`^2$`0/E"`$#YX`)`^4_X_Y>V__\71?C_
ME]:""Y'C`P`J````T```'I'!BD"I(0!`^7KX_Y<?(`/5_7N^J?T#`)'S"P#Y
M\P,`JOW\_Y=_`@#Q!!A`>H$``%3S"T#Y_7O"J,`#7]9@`D`Y@/__-.`#$ZJF
M^_^7FOO_EP$``-""`(#2(4`8D?'W_Y>`_O\UX`,3JO,+0/G]>\*HD?G_%P``
M`````````````/^#"M&A``#0XF,`D03@`)$&X`&1XP,"JOU[`*G]`P"1(<!'
M^24`0/GE3P'Y!0"`TH&$0/@E?$"2(?Q@TV$4`*EC0`"1WP`$ZT'__U1%``B1
M00!`^4(@`)%#!$#Y1!Q`^6,``<I!,$#Y(0`$RB$``\HC_%_3800!JB%\0))!
M/`#Y7P`%ZV'^_U0'*$"I)#./T@@D0:E$4*ORY9M!J2-TG=+B_%O3[/Q"TT(4
M!ZJ,>0>J(0$(RB/;K?(A``J*(0`)RJ4`!(LB0"*+0?U"TR%X"JI"``6+"Q!`
M^2U\0)*E`0C*Q@`$BT(`"PNE``>*I0`(RB$`#,I._%O33_Q"TZ4`"8O.%0*J
MI0`&BR$``HKB>0*JI0`."^:_0JDA``W*KOQ;TR$`"(O.%06JL/Q"T\8`!(OO
M`02+(0`&BX8!`LHA``X+C'U`DL8`!8K&``S*+OQ;T\8`#8O.%0&J#7H%JL8`
M#XO&``X+10`-RNX?0/E"?$"2I0`!BC#\0M.E``+*S@$$BZ4`#(O/_%O3#'H!
MJN\5!JJA`0S*I0`.B^XC0/FE``\+K7U`DB$`!HHA``W*S_Q"T^9Y!JHA``*+
MP@$$BZ[\6],A``*+K_Q"TX(!!LK.%06J+@`."T(`!8KE>06JC'U`DN&_1*E"
M``S*0@`-B\W]6].M%0ZJT'Q`DB$`!(M"``&+P0`%RDT`#0LA``Z*(0`0RL;]
M0M/B`02+SG@.JB$`#(NO_5O3IGQ`DB$``HOO%0VJH@`.RJ7]0M,O``\+I7@-
MJD(`#8KAMT6I0@`&RD(`$(OL_5O3C!4/JO#]0M,A``2+0@`!B\$!!<HA``^*
MSGU`DB$`#LI,``P+#WH/JJ(!!(LA``:+C?U;TR$``HNB``_*0@`,BJ5\0))"
M``7*K14,JD(`#HLM``T+\+M&J8;]0M/&>`RJH?U;TRP4#:KA`0;*(0`-BN]]
M0)(A``_*$`($BR$`!8M"`!"+L/U"TTP`#`L->@VJP@$$BR$``HO"``W*0@`,
MBL9\0))"``;*COU;TT(`#XO.%0RJ\+]'J2X`#@N%_4+3I7@,JL']6],L%`ZJ
MH0$%RB$`#HJM?4"2$`($BR$`#<I"`!"+T/U"TTP`#`L.>@ZJX@$$BR$`!HLA
M``*+H@`.RD(`#(JE?$"20@`%RH_]6]-"``V+[Q4,JO"W2*DO``\+AOU"T\9X
M#*KA_5O3+!0/JL$!!LHA``^*SGU`DA`"!(LA``[*0@`0B_#]0M-,``P+#WH/
MJJ(!!(LA``6+(0`"B\(`#\I"``R*QGQ`DD(`!LJ-_5O30@`.BZT5#*KPNTFI
M+0`-"X7]0M.E>`RJH?U;TRP4#:KA`07*(0`-BN]]0)(0`@2+(0`/RD(`$(NP
M_4+33``,"PUZ#:K"`02+(0`&BR$``HNB``W*COU;TZ5\0))"``R*SA4,JD(`
M!<HN``X+0@`/BX;]0M/AOTJIS'@,JL;]6]/&%`ZJ(0`$B^0!!(M"``&+H0$,
MRB$`#HJM?4"2(0`-RL_]0M/2``(+[GD.JB$`!8M"0":+[U]`^2$`!(N$`0[*
M1?Y;TX0``DJE%!*JX@$#BX0`#8M-_D+3L``!"[)Y$JJ$``*+XF-`^2%`)8O%
M`1+*!OY;TZ4``4K&%!"J00`#BPW^0M.B0"R+SP`$"ZUY$*I"``&+X6=`^81`
M)HM&`@W*Y?U;T\0`!$JE%`^J)@`#BX%`+HNQ``(+(0`&B^S]0M-"0"6+YFM`
M^8]Y#ZJE`0_*)/Y;TX04$:JE``)*P@`#BR;^0M.0``$+T7@1JN9O0/DA0"2+
MY`$1RJQ`,HN$``%*!?Y;TZ44$*J"`0*+P0`#BPS^0M.&0"V+K@`""Y!Y$*K!
M``&+YG-`^4)`)8LE`A#*Q/U;TZ(``DJ$%`ZJQ@`#BT)`+XO,_4+3C0`!"XYY
M#JI"``:+YG=`^2%`)(L$`@[*I?U;TX$``4JE%`VJQ@`#BR%`,8NO``(+(0`&
MBZS]0M-"0"6+YGM`^8UY#:K%`0W*Y/U;TX04#ZJE``)*P@`#B^;]0M.1``$+
MSW@/JN9_0/DA0"2+I`$/RJQ`,(N$``%*)?Y;TZ44$:J"`0*+P0`#BRS^0M.&
M0"Z+L``""XQY$:K!``&+YH-`^4)`)8OE`0S*!/Y;TZ(``DJ$%!"JQ@`#BT)`
M+8L-_D+3C@`!"T(`!HNF>1"J\(=`^2%`)(N$`0;*Q?U;TX$``4JE%`ZJ$`(#
MBR%`+XNM``(+(0`0B\_]0M-"0"6+\(M`^>YY#JK%``[*I/U;TX04#:JE``)*
M`@(#B[#]0M./``$+#7H-JO"/0/DA0"2+Q`$-RJQ`+(N$``%*Y?U;TZ44#ZJ&
M0":+`0(#BX(!`HOP_4+3K``""\$``8L&>@^J\)-`^4)`)8NE`0;*A/U;TZ(`
M`DJ$%`RJ$`(#BT)`+HN._4+3CP`!"\QY#*I"`!"+\)=`^2%`)(O$``S*Y?U;
MTX$``4JE%`^J$`(#BR%`+8OM_4+3K@`""Z]Y#ZHA`!"+\)M`^4)`)8N%`0_*
MQ/U;TZ(``DJ$%`ZJ0D`FBP4"`XO0_4+3C0`!"T4`!8L">@ZJ\)]`^2%`)(OD
M`0+*IOU;TX0``4K&%`VJ`0(#BX1`+(NP_4+3A``!BP%Z#:K.``4+I4`FBT8`
M`<K%``5*S/U;TZ5`+XO/_4+3C!4.JNYY#JKP/U2IC0$$"X1`+(NF_5O3QA0-
MJA`"`XNE`!"+,``.RLP`!0L0`@1*`D(BB^0!`XNP_4+3C_U;TPUZ#:KO%0RJ
M0@`$BZ5`)HODJT#Y0@`/"\8!#<K%``5*@P`#BX;]0M.A0"&+1/Q;T\QX#*J$
M%`*J(0`#BR$`!`NC`0RJY*]`^84!#0IC``**3_Q"TV,`!:J&FY?29N.Q\N)Y
M`JJ$``:+8T`NBR7\6],N_$+3I10!JF,`!(N$`0*J8P`%"X0``8K!>0&JY3M6
MJ4\`#`J$``^J;_Q"TX1`+8MM_%O3K14#JJ4`!HO.`0:+A``%BT4``:J$``T+
MI0`#BBT``@JE``VJC?Q;TZ5`+(OL>0.JI0`.BZ,5!*HM``RJHP`#"^Z[0/FE
M`02*C0$!"H_\0M.E``VJS@$&BZ5`(HMM_%O3XGD$JJT5`ZJ$`0*JI0`.B^Z_
M0/FE``T+A``#BDT`#`J$``VJ;_Q"T\X!!HN$0"&+K?Q;T^%Y`ZJM%06JA``.
MBX0`#0M#``&J[<-`^2X``@IC``6*K_Q"TV,`#JKE>06JK0$&BV-`+(N._%O3
M+``%JLX5!*IC``V+[<=`^6,`#@N,`02*K@`!"HP!#JJ._$+3@D$BBZP!!HMM
M_%O3Q'D$JJT5`ZI"``R+0@`-"ZP`!*KMRT#YC@`%"HP!`XIO_$+3C`$.JN-Y
M`ZJM`0:+@4$ABT[\6].,``.JSA4"JB$`#8LA``X+C`$"BFX`!`J,`0ZJ3OQ"
MT\)Y`JJ%026+[;M9J2_\0M.L`0:++?Q;TZT5`:JE``R+;``"JJ4`#0N,`0&*
M30`#"HP!#:KA>0&JS@$&BX1!)(NM_%O33``!JJT5!:J$``Z+[M=`^80`#0N,
M`06*+0`""HP!#:JO_$+3S@$&BX-!(XN-_%O3['D%JJT5!*HE``RJ8P`.BZ4`
M!(KNVT#Y8P`-"XT!`0J/_$+3I0`-JN1Y!*K.`0:+HD`BBVW\6].%`02JK14#
MJD(`#HONWT#Y0@`-"Z4``XJ-``P*;_Q"TZ4`#:K.`0:+H4`ABTW\6]/E>0.J
MK14"JH,`!:HA``Z+3OQ"TR$`#0MC``**PGD"JJ\`!`KM.URI8P`/JFQ`+(LC
M_%O38Q0!JB_\0M.M`0:+C`$-BZT``JJ#`0,+K`$!BDT`!0KA>0&JC`$-JFW\
M6].$022+S`$&BX0`#(M,``&J+@`""HP!`XJ,`0ZJK14#JH5!)8N$``T+[S-=
MJ6W\0M.M>0.JCOQ;T\X5!*KO`0:+HP`/BR4`#:IC``X+I0`$BJX!`0JE``ZJ
MCOQ"T\1Y!*JB0"*+A0$&BVS\6].,%0.J0@`%BV[\0M.E`02J0@`,"Z4``XK#
M>0.JCP`-"NP[7JFE``^JI4`ABT'\6],A%`*J3_Q"TXP!!HNE``R+C``#JJ4`
M`0N,`0**80`$"N)Y`JJ,`0&J4``#"H%!+8O-`0:+K/Q;TR$`#8N,%06J;0`"
MJN_[0/F.`0$+K0$%BBQ`+(NM`1"JT/U"TZ1!)(OM`0:+K_Q"T\;]6]/&%`ZJ
MA``-B^UY!:K2``0+[_]`^4$`#<HA``Q*Q3J8TD5,N?(A0".+[`$%BT/^6],.
M>@ZJ8Q02JB$`#(N$0":+[`-!^7$``0NF`0[*(4`CB\0`!$J&`06+@D`BBTS^
M0M,D_EO3DGD2JH04$:I"``:+[`=!^9```@O#`1+*)OY"TV,``4J!`06+;$`M
MBP/^6]/1>!&JC`$!BV,4$*I"0"2+Y@M!^6\`#`M$`A'*@T$CBX0``DKA_5O3
MP@`%BX9`+HL$_D+3Q@`"BY!X$*HA%`^JY`]!^2X`!@LB`A#*[/U"TT(``TJ#
M``6+1$`RB\+]6]./>0^JA``#BT(4#JK!0"&+XQ-!^4T`!`L&`@_*S/U"T\$`
M`4IF``6+(T`QBZ']6]..>0ZJ8P`&BR$4#:KL`0[*YA=!^3(``PN"0"*+84`A
MBX(!`DK$``6+3$`PBZ;]0M-"_EO3S7@-JH0!!(M"%!*JYAM!^5$`!`O#`0W*
M3/Y"TV$``4K#``6+)D`OBR'^6]/#``.+C'D2JB$4$:J"0"*+YA]!^3```PND
M`0S*84`ABX(``DK&``6+1$`NBR[^0M,"_EO3A``&BT(4$*K&>1&J[B-!^4\`
M!`N#`0;*@D`BBV$``4K.`06+(T`MBPW^0M/A_5O3L'D0JF,`#HLA%`^J[B=!
M^2T``PO$`!#*84`ABX(``DK$`06+3$`LB^[]0M.B_5O3SWD/JH0!!(M"%`VJ
M["M!^4X`!`L#`@_*@D`BBV$``4J#`06+)D`FBZS]0M/!_5O3PP`#BR$4#JJ&
M>0VJ["]!^2T``POD`0;*84`ABX(``DJ,`06+1$`PB]#]0M.B_5O3#GH.JH0`
M#(M"%`VJ[#-!^5$`!`O#``[*@D`BBV$``4J,`06+(T`OBZ_]0M,A_EO3[7D-
MJF,`#(LA%!&J[#=!^3```PO$`0W*+_Y"TX(``DJ$`06+3$`FBP+^6].&`02+
M0A00JNQY$:IA0"&+Y#M!^4\`!@NC`0S*PD`BBV$``4J#``6+)$`NBP[^0M/A
M_5O3A``#BR$4#ZK#>1"J\#]!^2X`!`N&`0/*@4`AB\(``DH0`@6+1D`MB^W]
M0M/"_5O3KWD/JD(4#JK&`!"+[4-!^5``!@MD``_*PD`BBX0``4JA`06+C$`L
MB\W]0M,$_EO3C`$!BZYY#JJ$%!"JX4=!^9$`#`OF`0[*YT`OB\8``DHB``6+
MPT`CBR'^6]-C``*+(101JF,``0L!_D+3[4M!^2%X$*J&022+P@$!RF3\6].L
M``"P1@`&2H04`ZJE`06+(OY"TX0`!HNE``>+AL%'^4)X$:HA``D+RP$+"V,`
M"@N$``4+2``("P0,`*D(!`&I"Q``^>!/0?G!`$#Y```!ZP$`@-*!``!4_7M`
MJ?^#"I'``U_6"O3_EQ\@`]7]>[^I`!"`TOT#`)&9]/^7'Q@`^29@A-(E<972
MQ)^;TL..BM("/IS2INBL\J7YO?)$%[/R0P:B\D)ZN/(&%`"I!`P!J0)\`JD?
M>`"Y_7O!J,`#7];]>[RI0GQ`D_T#`)'S4P&I%.``D?,#`:KU6P*I]0,`JO8#
M`JKW8P.I!8Q"J0!X0+FD#`(+OP`$ZV.4@YIB=$*+I(H"J>`"`#07"(!2]P(`
M2]\"%VN`PB"+U]*7&OA^0)/B`QBJTO/_EZ!Z0+G@`@`+H'H`N1\``7'```!4
M\U-!J?5;0JGW8T.I_7O$J,`#7];6`A=+<P(8B^`#%:JL^_^7W_X`<<T#`%36
M`@%1V'X&4Q<'`!'W:GK3=P(7BV`&0*F`!@"I<P(!D6(.?:F"#@&IX`,5JF(.
M?JF"#@*I8@Y_J8(.`ZF:^_^7?P(7ZX'^_U36&AA+X0,7JL)^0)/@`Q2JJ_/_
ME[9Z`+GS4T&I]5M"J?=C0ZG]>\2HP`-?UO<#$ZKU__\7'R`#U1\@`]7]>[RI
M_0,`D?-3`:GS`P&J]`,`JO5;`JGA#X`2]QL`^7?B`)%UVD*IH"(#4P($`!'A
MRB`XX,(BBU_@`'$M"P!4`0B`4B(``DL!`(!20GQ`D[3S_Y?@`Q.J<OO_EW_^
M`ZE__@2I?_X%J7\V`/G%_E#3Q/Y(TZ/^6-.B_E#3H?Y(T\#^6--@P@$YX`,3
MJF7&`3EDR@$Y=LX!.6/2`3EBU@$Y8=H!.77>`3E>^_^780)`^>`#$ZHA_%C3
M@0(`.6$"0/DA_%#3@08`.6$"0/DA_$C3@0H`.6$"0/F!#@`Y809`^2'\6-.!
M$@`Y809`^2'\4-.!%@`Y809`^2'\2-.!&@`Y809`^8$>`#EA"D#Y(?Q8TX$B
M`#EA"D#Y(?Q0TX$F`#EA"D#Y(?Q(TX$J`#EA"D#Y@2X`.6$.0/DA_%C3@3(`
M.6$.0/DA_%#3@38`.6$.0/DA_$C3@3H`.6$.0/F!/@`Y81)`^2'\6-.!0@`Y
M81)`^2'\4-.!1@`Y81)`^2'\2-.!2@`Y81)`^8%.`#GS4T&I]5M"J?<;0/G]
M>\2H%?/_%P$'@%(B``)+`0"`4D)\0)-<\_^7KO__%P``````````H```L`!`
M"I$!($$Y00,`-:$``)`B`(!2`B`!.2"D1_F@`0"T_7N_J:```+#]`P"1`/Q`
M^=_R_Y>@``"0`-1'^6`!`+3]>\&H(```D`#@&Y&,\_\7H```D`#41_G```"T
M(```D`#@&Y&&\_\7_7O!J,`#7];``U_6``````````"@``"P`4`*D0)`2CE"
M`0`UH@``D",`@%(#0`HY0+1'^:```+0A(`"1(```D`#@&Y$0\_\7P`-?U@``
M````````_7NZJ:,``)#]`P"18\!'^?-3`:GU6P*IXH<#J>+C`)'A`P&1X$\`
MN>`S`9%D`$#YY"\`^00`@-(N\_^7H```D*(``)``X$?Y0LQ'^>$#`JHX\_^7
MH```D`"P1_D``$`Y@`D`-$'0.]6S``"PH```D`"X1_D?(`/5'R`#U2-H8/CB
M3T"Y80A2.4`0`!%4#``1(00`,F$($CD`?'V3!?/_E^,#`*JA``"08H(+D>8C
M0/D```"0),A'^0!`'Y'E3T"Y`0``D,<`0/DA(!^1A`!`^6<$`*E#!`#Y9``!
MJ;\$`'$M"0!4(0"`TB`,`!'$>&'X(00`D638(/B_``%K;/__5*4,`!%U@@N1
M?]@E^.'__[#B`Q0J(<`DD00`@-*@#D#Y&//_ER`%`#1U@@N1]E,!D:`.0/FW
M\O^7]`,`*N$#%JH```"0`,`4D>;S_Y=`!`"T<X(+D6`.0/F:\O^7^?+_EZ``
M`)``P$?YX2]`^0(`0/DA``+K`@"`TN$$`%3@`Q0J\U-!J?5;0JG]>\:HP`-?
MUK#R_Y>S``"P8H(+D4`,`/E@`P"T=_+_ET'0.]6@``"0`+A'^1\@`]4?(`/5
M(&A@^!\8)#FJ__\7H`Y`^0GS_Y?6__\7H`I`^6```+15^O^7W/__%^$#%JH`
M``"0`.`2D;SS_Y>@"@#YP/K_M$WZ_Y?4__\7A0"`4K___Q<@`(!2+/+_EX/R
M_Y=P<U]S=')I;F=S(&UI<W-I;F<*```````O=&UP+P```"X`````````4$%2
M7U1-4$1)4@```````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````
M55-%4@````!54T523D%-10``````````)7,O)7,```!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````%!!
M4E]414U0``````````!005)?4%)/1TY!344`````.@`````````O````````
M`"5S)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`````
M`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!0
M05)?0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10``````
M``!005)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@``
M``````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````
M,0````````!L<V5E:R!F86EL960`````<F5A9"!F86EL960``````$Q$7TQ)
M0E)!4EE?4$%42`!365-414T``"4P,G@`````<&%R+0`````E<R5S)7,E<P``
M````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H```````!0051(`````'!A<FP`````+G!A<@``
M``!S:&]R="!R96%D````````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U
M)7,````E<R5S=&5M<"TE=2TE=25S```````````8`````````'!E<FP`````
M,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V,0```%5N86)L
M92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```````````M90```````"TM````````979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I
M>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%
M7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S
M:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@
M9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ
M92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY
M("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@
M("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D
M("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD[
M"FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I
M('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]
M"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\
M/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL
M96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64[
M"FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES
M=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<
M)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO
M=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*
M;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)
M0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO
M<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@
M<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A
M(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G
M:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG
M("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'
M24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I
M8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D
M8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U
M;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U
M9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE
M.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E
M="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`[
M"B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I
M<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II
M<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968[
M"B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S
M(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H
M;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD
M?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF
M("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D
M<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S
M(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@
M)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M
M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*
M<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E
M9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N
M86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A
M<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII
M9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C
M:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ
M6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M
M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=
M*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R
M86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!
M4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@
M/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I
M8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I
M"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H
M95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C
M86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I
M('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@
M,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P
M96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O
M;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D
M96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE
M=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@!P97)L>'-I+F,``````````$-!0TA%```!&P,[````_```
M`![__XM````!%/__BZ````%`__^,!````6S__XUP```!V/__CF0```)`__^/
MX````J#__Y!T```"R/__D6````+\__^3D````U#__Y/0```#</__E#````.4
M__^40````ZC__Y9D```$"/__EI````0L__^7````!&#__YO$```$G/__G#0`
M``2\__^<T```!-C__YY````%9/__GF````6$__^?A```!<#__Z5$```&,/__
MI\````9H__^H,```!LC__[B0```&[/__N.0```<,__^Z$```!U#__[O0```!
MK/__O%````&8__^\D```!I0`````````$``````!>E(`!'@>`1L,'P`````H
M````&/__BB0```!<`$$.,)T&G@5$E0)%E`.3!$K4TT+>W=4.`````````"@`
M``!$__^*6````&0`00XPG0:>!4*3!)0#0I4"4@K>W=73U`X`00L`````*```
M`'#__XJ0```!:`!!#D"=")X'0I0%DP9!E@.5!$&7`@`````````````0````
MG/__NK`````X`````````"@```"P__^Z'````'@`2@X0G0*>`4C>W0X`20X0
MG0*>`4'>W0X`````````9````-S__XN0````]`!!#D"=")X'0I,&E`5"F`&7
M`D:6`Y4$5M;50=C70][=T]0.`$$.0),&E`65!)8#EP*8`9T(G@=/UM5!V-=!
MWMW3U`X`00Y`DP:4!9T(G@="EP*8`4+8UP````!<```!1/__C!P```%X`$$.
MX`&=')X;2)09DQI$U--(WMT.`$$.X`&3&I09G1R>&T28%9<61)87E1AP"M33
M0=;50=C700M)T]35UM?80909DQI!EA>5&$&8%9<6```````D```!I/__C3@`
M``"4`$$.P`&=&)X71),65@K>W=,.`$$+````````,````<S__XVD````[`!!
M#K`(1)V&`9Z%`4.3A`%B"MW>TPX`00M."MW>TPX`00L``````%````(`__^.
M7````BP`00Y@G0R>"T.3"I0)3)4(E@>7!I@%?PK>W=?8U=;3U`X`00M)F@.9
M!%\*VME!"TG9VD*9!)H#0]G:09H#F01"VMD``````!P```)4__^0.````$``
M00X0G0*>`4C>W0X`````````(````G3__Y!8````7`!!#B"=!)X#0Y,"3M[=
MTPX`````````$````IC__Y"4````"`````````!<```"K/__D)````(D`$$.
M@`I"G:`!GI\!0Y.>`92=`4.5G`&6FP%<"MW>U=;3U`X`00M(F)D!EYH!19F8
M`7<*V-=!V4$+50K8UT'900M#U]C909B9`9>:`4&9F`$````@```##/__DE0`
M```L`$$.()T$G@-#DP)&WMW3#@`````````P```#,/__DEP```!L`$(.()T$
MG@-"DP)*"M[=TPX`00M#"M[=TPX`0@M#WMW3#@``````.````V3__Y*8```$
MQ`!!#F"=#)X+1)4(E@="DPJ4"467!I@%F00#`1H*WMW9U]C5UM/4#@!!"P``
M````'````Z#__Y<@````<`!!#B"=!)X#5PK>W0X`00L````8```#P/__EW``
M``"<`$$.H`*=))XC````````B````]S__Y?P```!;`!!#E!"#M"`!$2=BD">
MB4!#DXA`E(=`39:%0)6&0$28@T"7A$!BUM5"V-=*W=[3U$$.@(`$00X`00[0
M@`23B$"4AT"5AD"6A4"7A$"8@T"=BD">B4!&UM5!V-="E89`EH5`EX1`F(-`
M0]76U]A!EH5`E89`09B#0)>$0``````<```$:/__F-0````@`$$.$)T"G@%&
MWMT.`````````#@```2(__^8U````20`00Y`G0B>!T:3!I0%E026`U@*WMW5
MUM/4#@!!"TT*WMW5UM/4#@!!"P```````&P```3$__^9O```!<``00Z0`YTR
MGC%(DS"4+Y4NEBU#ERR8*UR:*9DJ`EH*VME!WMW7V-76T]0.`$$+`IG9VDW>
MW=?8U=;3U`X`00Z0`Y,PE"^5+I8MERR8*YDJFBF=,IXQ`D/9VD&:*9DJ````
M```T```%-/__GPP```)X`$$.4)T*G@E$DPB4!T:5!I8%0Y<$F`,"9PK>W=?8
MU=;3U`X`00L``````"@```5L__^A4````&0`00X@G02>`T*3`D<*WMW3#@!!
M"TW>W=,.````````,```!9C__[7T```"&`!!#F"=#)X+19,*E`F5")8'`ET*
MWMW5UM/4#@!!"P```````````"````7,__^A8```$%P`00Z@!4:=5)Y3`P0.
M"MW>#@!!"P```!P```7P__^QG````%0`00X0G0*>`5/>W0X`````````0```
M!A#__['0```!)`!!#D"=")X'0Y,&E`5#E026`T.7`I@!60K>W=?8U=;3U`X`
M00MB"M[=U]C5UM/4#@!!"P`````P```&5/__LK@```&X`$$.0)T(G@="DP:4
M!465!)8#EP("7PK>W=?5UM/4#@!!"P``````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!1L````````%$P````
M`````````````````0`````````!``````````$````````"60`````````!
M`````````F,``````````0````````*F``````````$````````"Q0``````
M```/````````!%X`````````&0```````9U``````````!L`````````"```
M```````:```````!G4@`````````'``````````(``````````0````````"
M2``````````%````````#P``````````!@````````5P``````````H`````
M```$J``````````+`````````!@`````````%0````````````````````,`
M``````&?Z``````````"````````!=``````````%``````````'````````
M`!<````````6P``````````'````````$Z@`````````"`````````,8````
M``````D`````````&`````!O___[``````@`````````;___^0`````````7
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````&=6```
M`````9U0`````````````````````````````9U`````````````````````
M```````````````````!HP```````````````````9U(```````!HG``````
M``````````````````````````````````&=6```````````````````````
M``````&BB``````````````````!H?`````````ZI```````````````````
M`````````````````````!R0````````')`````````<D````````!R0````
M````')`````````<D````````!R0````````')`````````<D````````!R0
M````````')`````````<D````````!R0````````')`````````<D```````
M`!R0````````')`````````<D````````!R0````````')`````````<D```
M`````!R0````````')`````````<D````````!R0````````')`````````<
MD````````!R0````````')`````````<D````````!R0````````')``````
M```<D````````!R0````````')`````````<D````````!R0````````')``
M```````<D````````!R0````````')`````````<D````````!R0````````
M')`````````<D````````!R0````````')`````````<D````````!R0````
M````')`````````<D````````!R0````````')`````````<D````````!R0
M````````')`````````<D````````!R0````````')`````````<D```````
M`!R0````````')````````&B@````````:'X"E!!4BYP;0H`````````````
M`````%0@````````5"@``````````````````%0P````````5$````````!4
M2````````%10````````5%@``````````````````%1@````````5&@`````
M`````````````%?81T-#.B`H3F5T0E-$(&YB,B`R,#(S,#<Q,"D@,3`N-2XP
M`$=#0SH@*$YE=$)31"!N8C,@,C`R,S$P,#@I(#$P+C4N,``D3F5T0E-$.B!C
M<G0P+E,L=B`Q+C(@,C`Q."\Q,2\R-B`Q-SHS-SHT-"!J;V5R9R!%>'`@)``D
M3F5T0E-$.B!C<G0P+6-O;6UO;BYC+'8@,2XR-R`R,#(R+S`V+S(Q(#`V.C4R
M.C$W('-K<FQL($5X<"`D`"1.971"4T0Z(&-R=&DN4RQV(#$N,2`R,#$T+S`X
M+S$P(#`U.C0W.C,V(&UA='0@17AP("0`)$YE=$)31#H@8W)T8F5G:6XN8RQV
M(#$N,3<@,C`Q."\Q,B\R."`Q.#HQ-SHQ,2!C:')I<W1O<R!%>'`@)``D3F5T
M0E-$.B!C<G1E;F0N4RQV(#$N,2`R,#$T+S`X+S$P(#`U.C0W.C,V(&UA='0@
M17AP("0``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+FYE=&)S9"YI9&5N=``N
M;F]T92YN971B<V0N<&%X`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L82YD
M>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?
M9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9'EN86UI8P`N
M9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````
M````````````````````````````````````````````````````````````
M```````````````````````+`````0`````````"`````````@`````````"
M```````````7`````````````````````0``````````````$P````<`````
M`````@````````(8`````````A@`````````&`````````````````````0`
M`````````````"8````'``````````(````````",`````````(P````````
M`!0````````````````````$```````````````W````!0`````````"````
M`````D@````````"2`````````,D````!0``````````````"``````````$
M````/0````L``````````@````````5P````````!7`````````)D`````8`
M```#``````````@`````````&````$4````#``````````(````````/````
M``````\`````````!*@````````````````````!``````````````!-````
M!``````````"````````$Z@````````3J`````````,8````!0``````````
M````"``````````8````5P````0`````````0@```````!;`````````%L``
M```````%T`````4````3``````````@`````````&````%P````!````````
M``8````````<D````````!R0````````!``````````````````````0````
M`````!````!A`````0`````````&````````()`````````@D````````#-X
M````````````````````$```````````````9P````$``````````@``````
M`%0(````````5`@```````!!5P````````````````````@`````````````
M`&\````!``````````(```````"58````````)5@`````````/P`````````
M```````````$``````````````!]`````0`````````"````````EF``````
M``"68`````````:,````````````````````"```````````````AP````X`
M`````````P```````9U`````````G4``````````"```````````````````
M``@`````````"````),````/``````````,```````&=2````````)U(````
M``````@````````````````````(``````````@```"?`````0`````````#
M```````!G5````````"=4``````````(````````````````````"```````
M````````I`````8``````````P```````9U8````````G5@````````!X```
M``8```````````````@`````````$````*T````!``````````,```````&?
M.````````)\X`````````+`````````````````````(``````````@```"R
M`````0`````````#```````!G^@```````"?Z`````````((````````````
M````````"``````````(````NP````$``````````P```````:'P````````
MH?``````````B`````````````````````@``````````````,$````(````
M``````,```````&B@````````*)X`````````(@```````````````````!`
M``````````````#&`````0`````````P``````````````````"B>```````
M``!$`````````````````````0`````````!````'P````$`````````,```
M````````````````HKP````````!'@````````````````````$`````````
M`0````$````#`````````````````````````````*/:`````````,\`````
4```````````````!````````````
